import copy

import oaix

import myass.config


class Assistant:
    def __init__(self, name):
        self.config = myass.config.Config(name)
        self.api = oaix.Api()
        self.messages = []

    def __call__(self, content=None, messages=None):
        params = copy.deepcopy(self.config.flatten())
        if messages is not None:
            self.messages.extend(messages)
        if content is not None:
            self.messages.append({'role': 'user', 'content': content})
        params['messages'].extend(self.messages)
        r = self.api.post('chat/completions', json=params)
        self.messages.append(r['choices'][0]['message'])
        return r['choices'][0]['message']['content']



import atexit
import os
import readline

import appdirs


def init(appname='myass', filename='history'):
    data_dir = appdirs.user_data_dir(appname)
    if not os.path.exists(data_dir):
        os.mkdir(data_dir)
    histfile = os.path.join(data_dir, filename)
    try:
        readline.read_history_file(histfile)
    except FileNotFoundError:
        pass
    atexit.register(readline.write_history_file, histfile)
